@@ -33,6 +33,7 @@
 #include "select-game.h"
 #include "game-settings.h"
 #include "game-rules.h"
+#include "metaserver.h"
 
 const int PRIVATE_GAME_HISTORY_SIZE = 10;
 
@@ -200,24 +201,19 @@ void connect_set_server(const gchar * server)
 	connect_set_field(&connect_server, server);
 }
 
-static const gchar *connect_get_meta_server(void)
+static gchar *connect_get_meta_server(void)
 {
-	const gchar *text;
-
 	if (meta_server_entry == NULL)
 		return NULL;
-	text = gtk_entry_get_text(GTK_ENTRY(meta_server_entry));
-	while (*text != '\0' && isspace(*text))
-		text++;
-	return text;
+	return metaserver_get(METASERVER(meta_server_entry));
 }
 
 void connect_set_meta_server(const gchar * meta_server)
 {
 	connect_set_field(&metaserver_info.server, meta_server);
 	if (meta_server_entry != NULL)
-		gtk_entry_set_text(GTK_ENTRY(meta_server_entry),
-				   metaserver_info.server);
+		metaserver_add(METASERVER(meta_server_entry),
+			       metaserver_info.server);
 }
 
 const gchar *connect_get_port(void)
@@ -246,6 +242,8 @@ static void connect_close_all(gboolean user_pressed_ok,
 {
 	connect_viewer_allowed = can_be_viewer;
 	if (user_pressed_ok) {
+		gchar *meta_server;
+
 		connect_set_field(&connect_name,
 				  gtk_entry_get_text(GTK_ENTRY
 						     (name_entry)));
@@ -253,8 +251,9 @@ static void connect_close_all(gboolean user_pressed_ok,
 		    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
 						 (viewer_toggle));
 		/* Save connect dialogue entries */
-		config_set_string("connect/meta-server",
-				  connect_get_meta_server());
+		meta_server = connect_get_meta_server();
+		config_set_string("connect/meta-server", meta_server);
+		g_free(meta_server);
 		config_set_string("connect/name", connect_name);
 		config_set_int("connect/viewer", connect_viewer);
 
@@ -378,8 +377,8 @@ static void meta_create_notify(NetEvent event,
 				connect_set_field(&connect_port, line + 5);
 			else if (strcmp(line, "started") == 0) {
 				log_message(MSG_INFO,
-					    _
-					    ("New game server requested on %s port %s\n"),
+					    _(""
+					      "New game server requested on %s port %s\n"),
 					    connect_server, connect_port);
 				/* The meta server is now busy creating the new game.
 				 * UGLY FIX: Wait for some time */
@@ -387,8 +386,8 @@ static void meta_create_notify(NetEvent event,
 				connect_close_all(TRUE, FALSE);
 			} else
 				log_message(MSG_ERROR,
-					    _
-					    ("Unknown message from the metaserver: %s\n"),
+					    _(""
+					      "Unknown message from the metaserver: %s\n"),
 					    line);
 			break;
 		}
@@ -468,8 +467,8 @@ static void meta_notify(NetEvent event, G_GNUC_UNUSED void *user_data,
 				net_close(ses);
 				if (metaserver_info.num_redirects++ == 10) {
 					log_message(MSG_INFO,
-						    _
-						    ("Too many meta-server redirects\n"));
+						    _(""
+						      "Too many meta-server redirects\n"));
 					return;
 				}
 				split_result = g_strsplit(line, " ", 0);
@@ -495,8 +494,8 @@ static void meta_notify(NetEvent event, G_GNUC_UNUSED void *user_data,
 							  port);
 				} else {
 					log_message(MSG_ERROR,
-						    _
-						    ("Bad redirect line: %s\n"),
+						    _(""
+						      "Bad redirect line: %s\n"),
 						    line);
 				};
 				g_strfreev(split_result);
@@ -521,9 +520,9 @@ static void meta_notify(NetEvent event, G_GNUC_UNUSED void *user_data,
 			}
 			if (metaserver_info.version_major < 1) {
 				log_message(MSG_INFO,
-					    _
-					    ("Meta server too old to create "
-					     "servers (version %d.%d)\n"),
+					    _(""
+					      "Meta server too old to create "
+					      "servers (version %d.%d)\n"),
 					    metaserver_info.version_major,
 					    metaserver_info.version_minor);
 			} else {
@@ -598,8 +597,8 @@ static void meta_notify(NetEvent event, G_GNUC_UNUSED void *user_data,
 				    if (!strcmp
 					(argument, "reroll first 2")) {
 					server_sevenrule =
-					    g_strdup(_
-						     ("Reroll on 1st 2 turns"));
+					    g_strdup(_(""
+						       "Reroll on 1st 2 turns"));
 				} else if (!strcmp(argument, "reroll all")) {
 					server_sevenrule =
 					    g_strdup(_("Reroll all 7s"));
@@ -649,11 +648,11 @@ static void query_meta_server(const gchar * server, const gchar * port)
 {
 	if (metaserver_info.num_redirects > 0)
 		log_message(MSG_INFO,
-			    _
-			    ("Redirected to meta-server at %s, port %s\n"),
+			    _(""
+			      "Redirected to meta-server at %s, port %s\n"),
 			    server, port);
-	show_waiting_box(_
-			 ("Receiving a list of Pioneers servers from the meta server.\n"),
+	show_waiting_box(_(""
+			   "Receiving a list of Pioneers servers from the meta server.\n"),
 			 server, port);
 
 	ses = net_new(meta_notify, NULL);
@@ -689,9 +688,6 @@ static GtkWidget *build_create_interface(void)
 	GtkWidget *label;
 	GtkObject *adj;
 	guint row;
-	GtkTooltips *tooltips;
-
-	tooltips = gtk_tooltips_new();
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
@@ -745,8 +741,8 @@ static GtkWidget *build_create_interface(void)
 	gtk_table_attach(GTK_TABLE(game_settings), aiplayers_spin,
 			 1, 2, row, row + 1,
 			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_tooltips_set_tip(tooltips, aiplayers_spin,
-			     _("The number of AI players"), NULL);
+	gtk_widget_set_tooltip_text(aiplayers_spin,
+				    _("The number of AI players"));
 
 	game_rules = game_rules_new_metaserver();
 	gtk_widget_show(game_rules);
@@ -921,13 +917,7 @@ static void set_meta_serverinfo(void)
 {
 	gchar *meta_tmp;
 
-	meta_tmp =
-	    g_strdup(gtk_entry_get_text(GTK_ENTRY(meta_server_entry)));
-	if (meta_tmp[0] == '\0') {
-		g_free(meta_tmp);
-		meta_tmp = get_meta_server_name(TRUE);
-		gtk_entry_set_text(GTK_ENTRY(meta_server_entry), meta_tmp);
-	}
+	meta_tmp = metaserver_get(METASERVER(meta_server_entry));
 	metaserver_info.server = meta_tmp;	/* Take-over of the pointer */
 	if (!metaserver_info.port)
 		metaserver_info.port =
@@ -940,7 +930,6 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 	GtkWidget *dlg_vbox;
 	GtkWidget *vbox;
 	GtkWidget *scroll_win;
-	GtkTooltips *tooltips;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 
@@ -960,8 +949,6 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 		return;
 	}
 
-	tooltips = gtk_tooltips_new();
-
 	meta_dlg = gtk_dialog_new_with_buttons(_("Join a public game"),
 					       GTK_WINDOW(parent),
 					       0,
@@ -978,24 +965,19 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 	g_signal_connect(G_OBJECT(meta_dlg), "response",
 			 G_CALLBACK(meta_dlg_cb), NULL);
 	gtk_widget_realize(meta_dlg);
-	gtk_tooltips_set_tip(tooltips,
-			     gui_get_dialog_button(GTK_DIALOG(meta_dlg),
-						   0),
-			     _("Refresh the list of games"), NULL);
-	gtk_tooltips_set_tip(tooltips,
-			     gui_get_dialog_button(GTK_DIALOG(meta_dlg),
-						   1),
-			     _
-			     ("Create a new public game at the meta server"),
-			     NULL);
-	gtk_tooltips_set_tip(tooltips,
-			     gui_get_dialog_button(GTK_DIALOG(meta_dlg),
-						   2),
-			     _("Don't join a public game"), NULL);
-	gtk_tooltips_set_tip(tooltips,
-			     gui_get_dialog_button(GTK_DIALOG(meta_dlg),
-						   3),
-			     _("Join the selected game"), NULL);
+	gtk_widget_set_tooltip_text(gui_get_dialog_button
+				    (GTK_DIALOG(meta_dlg), 0),
+				    _("Refresh the list of games"));
+	gtk_widget_set_tooltip_text(gui_get_dialog_button
+				    (GTK_DIALOG(meta_dlg), 1),
+				    _(""
+				      "Create a new public game at the meta server"));
+	gtk_widget_set_tooltip_text(gui_get_dialog_button
+				    (GTK_DIALOG(meta_dlg), 2),
+				    _("Don't join a public game"));
+	gtk_widget_set_tooltip_text(gui_get_dialog_button
+				    (GTK_DIALOG(meta_dlg), 3),
+				    _("Join the selected game"));
 
 	dlg_vbox = GTK_DIALOG(meta_dlg)->vbox;
 	gtk_widget_show(dlg_vbox);
@@ -1029,8 +1011,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 	    gtk_tree_view_new_with_model(GTK_TREE_MODEL(meta_games_model));
 	gtk_widget_show(meta_games_view);
 	gtk_container_add(GTK_CONTAINER(scroll_win), meta_games_view);
-	gtk_tooltips_set_tip(tooltips, meta_games_view,
-			     _("Select a game to join"), NULL);
+	gtk_widget_set_tooltip_text(meta_games_view,
+				    _("Select a game to join"));
 
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Map Name"),
@@ -1040,8 +1022,7 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
 	gtk_tree_view_column_set_sort_column_id(column, C_META_MAP);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Name of the game"), NULL);
+	gtk_widget_set_tooltip_text(column->button, _("Name of the game"));
 
 	renderer = gtk_cell_renderer_text_new();
 	g_object_set(renderer, "xalign", 1.0f, NULL);
@@ -1051,8 +1032,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Number of players in the game"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Number of players in the game"));
 
 	renderer = gtk_cell_renderer_text_new();
 	g_object_set(renderer, "xalign", 1.0f, NULL);
@@ -1062,8 +1043,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Maximum players for the game"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Maximum players for the game"));
 
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Terrain"),
@@ -1072,8 +1053,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     C_META_TERRAIN, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Random of default terrain"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Random of default terrain"));
 
 	renderer = gtk_cell_renderer_text_new();
 	g_object_set(renderer, "xalign", 1.0f, NULL);
@@ -1083,8 +1064,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     C_META_VICTORY, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Points needed to win"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Points needed to win"));
 
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Sevens Rule"),
@@ -1093,8 +1074,7 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     C_META_SEVENS, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button, _("Sevens rule"),
-			     NULL);
+	gtk_widget_set_tooltip_text(column->button, _("Sevens rule"));
 
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Host"),
@@ -1104,8 +1084,7 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
 	gtk_tree_view_column_set_sort_column_id(column, C_META_HOST);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Host of the game"), NULL);
+	gtk_widget_set_tooltip_text(column->button, _("Host of the game"));
 
 	renderer = gtk_cell_renderer_text_new();
 	g_object_set(renderer, "xalign", 1.0f, NULL);
@@ -1115,8 +1094,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Port of the the game"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Port of the the game"));
 
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Version"),
@@ -1125,8 +1104,8 @@ static void create_meta_dlg(G_GNUC_UNUSED GtkWidget * widget,
 						     C_META_VERSION, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(meta_games_view),
 				    column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Version of the host"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Version of the host"));
 
 	/* Register double-click */
 	g_signal_connect(G_OBJECT(meta_games_view), "button_press_event",
@@ -1171,7 +1150,6 @@ void connect_create_dlg(void)
 	GtkWidget *hbox;
 	GtkWidget *btn;
 	GtkWidget *sep;
-	GtkTooltips *tooltips;
 	gchar *fullname;
 
 	if (connect_dlg) {
@@ -1179,8 +1157,6 @@ void connect_create_dlg(void)
 		return;
 	}
 
-	tooltips = gtk_tooltips_new();
-
 	connect_dlg = gtk_dialog_new_with_buttons(_("Start a new game"),
 						  GTK_WINDOW(app_window),
 						  0,
@@ -1219,8 +1195,7 @@ void connect_create_dlg(void)
 
 	gtk_table_attach(GTK_TABLE(table), name_entry, 1, 2, 0, 1,
 			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_tooltips_set_tip(tooltips, name_entry,
-			     _("Enter your name"), NULL);
+	gtk_widget_set_tooltip_text(name_entry, _("Enter your name"));
 
 	viewer_toggle = gtk_check_button_new_with_label(_("Viewer"));
 	gtk_widget_show(viewer_toggle);
@@ -1229,8 +1204,8 @@ void connect_create_dlg(void)
 
 	gtk_table_attach(GTK_TABLE(table), viewer_toggle, 2, 3, 0, 1, 0,
 			 GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_tooltips_set_tip(tooltips, viewer_toggle,
-			     _("Do you want to be a viewer?"), NULL);
+	gtk_widget_set_tooltip_text(viewer_toggle,
+				    _("Do you want to be a viewer?"));
 
 	sep = gtk_hseparator_new();
 	gtk_widget_show(sep);
@@ -1244,16 +1219,13 @@ void connect_create_dlg(void)
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(lbl), 0, 0.5);
 
-	meta_server_entry = gtk_entry_new();
+	meta_server_entry = metaserver_new();
 	gtk_widget_show(meta_server_entry);
 	gtk_table_attach(GTK_TABLE(table), meta_server_entry, 1, 3, 2, 3,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
 			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_entry_set_text(GTK_ENTRY(meta_server_entry),
-			   metaserver_info.server);
-	gtk_tooltips_set_tip(tooltips, meta_server_entry,
-			     _("Leave empty for the default meta server"),
-			     NULL);
+	metaserver_add(METASERVER(meta_server_entry),
+		       metaserver_info.server);
 
 	hbox = gtk_hbox_new(FALSE, 3);
 	gtk_widget_show(hbox);
@@ -1265,14 +1237,14 @@ void connect_create_dlg(void)
 	gtk_box_pack_start_defaults(GTK_BOX(hbox), btn);
 	g_signal_connect(G_OBJECT(btn), "clicked",
 			 G_CALLBACK(create_meta_dlg), app_window);
-	gtk_tooltips_set_tip(tooltips, btn, _("Join a public game"), NULL);
+	gtk_widget_set_tooltip_text(btn, _("Join a public game"));
 	GTK_WIDGET_SET_FLAGS(btn, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default(btn);
 
 	btn = gtk_button_new_with_label(_("Create game"));
 	gtk_widget_show(btn);
 	gtk_box_pack_start_defaults(GTK_BOX(hbox), btn);
-	gtk_tooltips_set_tip(tooltips, btn, _("Create a game"), NULL);
+	gtk_widget_set_tooltip_text(btn, _("Create a game"));
 	g_signal_connect(G_OBJECT(btn), "clicked",
 			 G_CALLBACK(launch_server_gtk), app_window);
 	fullname = g_find_program_in_path(PIONEERS_SERVER_GTK_PATH);
@@ -1285,8 +1257,7 @@ void connect_create_dlg(void)
 	btn = gtk_button_new_with_label(_("Join private game"));
 	gtk_widget_show(btn);
 	gtk_box_pack_start_defaults(GTK_BOX(hbox), btn);
-	gtk_tooltips_set_tip(tooltips, btn,
-			     _("Join a private game"), NULL);
+	gtk_widget_set_tooltip_text(btn, _("Join a private game"));
 	g_signal_connect(G_OBJECT(btn), "clicked",
 			 G_CALLBACK(connect_private_dialog), app_window);
 
@@ -1414,7 +1385,6 @@ static void connect_private_dialog(G_GNUC_UNUSED GtkWidget * widget,
 	GtkWidget *table;
 	GtkWidget *lbl;
 	GtkWidget *hbox;
-	GtkTooltips *tooltips;
 
 	GtkWidget *host_list;
 	GPtrArray *host_entries;
@@ -1428,8 +1398,6 @@ static void connect_private_dialog(G_GNUC_UNUSED GtkWidget * widget,
 		return;
 	}
 
-	tooltips = gtk_tooltips_new();
-
 	connect_private_dlg =
 	    gtk_dialog_new_with_buttons(_("Join a private game"),
 					GTK_WINDOW(parent), 0,
@@ -1471,8 +1439,8 @@ static void connect_private_dialog(G_GNUC_UNUSED GtkWidget * widget,
 			 GTK_EXPAND | GTK_FILL,
 			 GTK_EXPAND | GTK_FILL, 0, 0);
 	gtk_entry_set_text(GTK_ENTRY(host_entry), connect_server);
-	gtk_tooltips_set_tip(tooltips, host_entry,
-			     _("Name of the host of the game"), NULL);
+	gtk_widget_set_tooltip_text(host_entry,
+				    _("Name of the host of the game"));
 	connect_set_field(&connect_server, connect_server);
 
 	lbl = gtk_label_new(_("Server Port"));
@@ -1490,8 +1458,8 @@ static void connect_private_dialog(G_GNUC_UNUSED GtkWidget * widget,
 	gtk_widget_show(port_entry);
 	gtk_box_pack_start(GTK_BOX(hbox), port_entry, FALSE, TRUE, 0);
 	gtk_entry_set_text(GTK_ENTRY(port_entry), connect_port);
-	gtk_tooltips_set_tip(tooltips, port_entry,
-			     _("Port of the host of the game"), NULL);
+	gtk_widget_set_tooltip_text(port_entry,
+				    _("Port of the host of the game"));
 	connect_set_field(&connect_port, connect_port);
 
 	host_list = gtk_combo_box_new_text();
@@ -1531,7 +1499,7 @@ static void connect_private_dialog(G_GNUC_UNUSED GtkWidget * widget,
 
 	gtk_table_attach(GTK_TABLE(table), host_list, 1, 2, 2, 3,
 			 GTK_FILL, GTK_FILL, 0, 0);
-	gtk_tooltips_set_tip(tooltips, host_list, _("Recent games"), NULL);
+	gtk_widget_set_tooltip_text(host_list, _("Recent games"));
 
 	lbl = gtk_label_new(_("Recent Games"));
 	gtk_widget_show(lbl);
