@@ -37,6 +37,8 @@
 #include "histogram.h"
 #include "theme.h"
 #include "config-gnome.h"
+#include "gtkbugs.h"
+#include "audio.h"
 
 static GtkWidget *preferences_dlg;
 GtkWidget *app_window;		/* main application window */
@@ -59,7 +61,7 @@ enum {
 static GtkWidget *map_notebook;	/* map area panel */
 static GtkWidget *trade_page;	/* trade page in map area */
 static GtkWidget *quote_page;	/* quote page in map area */
-static GtkWidget *legend_page;	/* splash page in map area */
+static GtkWidget *legend_page;	/* legend page in map area */
 static GtkWidget *splash_page;	/* splash page in map area */
 
 static GtkWidget *develop_notebook;	/* development card area panel */
@@ -522,17 +524,24 @@ void gui_show_legend_page(gboolean show)
 		gtk_widget_hide(legend_page);
 }
 
-void gui_show_splash_page(gboolean show)
+void gui_show_splash_page(gboolean show, GtkWidget * chat_widget)
 {
+	static GtkWidget *widget = NULL;
+	if (chat_widget != NULL)
+		widget = chat_widget;
+	g_assert(widget != NULL);
+
 	chat_set_grab_focus_on_update(TRUE);
 	if (show) {
 		gtk_widget_show(splash_page);
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook),
 					      SPLASH_PAGE);
+		gtk_widget_hide(widget);
 	} else {
 		gtk_widget_hide(splash_page);
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(map_notebook),
 					      MAP_PAGE);
+		gtk_widget_show(widget);
 	}
 }
 
@@ -605,7 +614,6 @@ static GtkWidget *build_map_panel(void)
 	splash_page = splash_build_page();
 	gtk_notebook_insert_page(GTK_NOTEBOOK(map_notebook),
 				 splash_page, lbl, SPLASH_PAGE);
-	gui_show_splash_page(TRUE);
 
 	return map_notebook;
 }
@@ -749,7 +757,7 @@ static GtkWidget *build_main_interface(void)
 	gtk_paned_pack1(GTK_PANED(vpaned), build_map_panel(), TRUE, TRUE);
 
 	chat_panel = gtk_vbox_new(FALSE, 0);
-	gtk_widget_show(chat_panel);
+	gui_show_splash_page(TRUE, chat_panel);
 
 	panel = chat_build_panel();
 	frontend_gui_register(panel, GUI_DISCONNECT, NULL);
@@ -818,6 +826,19 @@ static void summary_color_cb(GtkToggleButton * widget,
 	set_color_summary(color_summary);
 }
 
+static void silent_mode_cb(GtkToggleButton * widget,
+			   G_GNUC_UNUSED gpointer user_data)
+{
+	GtkToggleButton *announce_button = user_data;
+
+	gboolean silent_mode = gtk_toggle_button_get_active(widget);
+	config_set_int("settings/silent_mode", silent_mode);
+	set_silent_mode(silent_mode);
+	gtk_toggle_button_set_inconsistent(announce_button, silent_mode);
+	gtk_widget_set_sensitive(GTK_WIDGET(announce_button),
+				 !silent_mode);
+}
+
 static void announce_player_cb(GtkToggleButton * widget,
 			       G_GNUC_UNUSED gpointer user_data)
 {
@@ -846,12 +867,12 @@ static void toolbar_shortcuts_cb(void)
 
 static void preferences_cb(void)
 {
+	GtkWidget *silent_mode_widget;
 	GtkWidget *widget;
 	GtkWidget *dlg_vbox;
 	GtkWidget *theme_label;
 	GtkWidget *theme_list;
 	GtkWidget *layout;
-	GtkTooltips *tooltips;
 
 	guint row;
 	gint color_summary;
@@ -864,8 +885,8 @@ static void preferences_cb(void)
 	};
 
 	/* Caption of preferences dialog */
-	preferences_dlg = gtk_dialog_new_with_buttons(_
-						      ("Pioneers Preferences"),
+	preferences_dlg = gtk_dialog_new_with_buttons(_(""
+							"Pioneers Preferences"),
 						      GTK_WINDOW
 						      (app_window),
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -881,8 +902,6 @@ static void preferences_cb(void)
 			 G_CALLBACK(gtk_widget_destroy), NULL);
 	gtk_widget_show(preferences_dlg);
 
-	tooltips = gtk_tooltips_new();
-
 	dlg_vbox = GTK_DIALOG(preferences_dlg)->vbox;
 	gtk_widget_show(dlg_vbox);
 
@@ -916,9 +935,9 @@ static void preferences_cb(void)
 				  0, 1, row, row + 1);
 	gtk_table_attach_defaults(GTK_TABLE(layout), theme_list,
 				  1, 2, row, row + 1);
-	/* Tooltip for changing the theme in the preferences dialog */
-	gtk_tooltips_set_tip(tooltips, theme_list,
-			     _("Choose one of the themes"), NULL);
+	gtk_widget_set_tooltip_text(theme_list,
+				    /* Tooltip for changing the theme in the preferences dialog */
+				    _("Choose one of the themes"));
 	row++;
 
 	/* Label for the option to show the legend */
@@ -930,10 +949,10 @@ static void preferences_cb(void)
 			 G_CALLBACK(show_legend_cb), NULL);
 	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
 				  0, 2, row, row + 1);
-	gtk_tooltips_set_tip(tooltips, widget,
-			     /* Tooltip for the option to show the legend */
-			     _("Show the legend as a page beside the map"),
-			     NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for the option to show the legend */
+				    _(""
+				      "Show the legend as a page beside the map"));
 	row++;
 
 	/* Label for the option to display log messages in color */
@@ -945,14 +964,15 @@ static void preferences_cb(void)
 				     color_messages_enabled);
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(message_color_cb), NULL);
-	/* Tooltip for the option to display log messages in color */
-	gtk_tooltips_set_tip(tooltips, widget,
-			     _("Show new messages with color"), NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for the option to display log messages in color */
+				    _("Show new messages with color"));
 	row++;
 
-	/* Label for the option to display chat in color of player */
-	widget = gtk_check_button_new_with_label(_
-						 ("Chat in color of player"));
+	widget = gtk_check_button_new_with_label(
+							/* Label for the option to display chat in color of player */
+							_(""
+							  "Chat in color of player"));
 	gtk_widget_show(widget);
 	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
 				  0, 2, row, row + 1);
@@ -960,11 +980,10 @@ static void preferences_cb(void)
 				     color_chat_enabled);
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(chat_color_cb), NULL);
-	gtk_tooltips_set_tip(tooltips, widget,
-			     /* Tooltip for the option to display chat in color of player */
-			     _
-			     ("Show new chat messages in the color of the player"),
-			     NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for the option to display chat in color of player */
+				    _(""
+				      "Show new chat messages in the color of the player"));
 	row++;
 
 	/* Label for the option to display the summary with colors */
@@ -977,13 +996,13 @@ static void preferences_cb(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), color_summary);	/* @todo RC use correct variable */
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(summary_color_cb), NULL);
-	/* Tooltip for the option to display the summary with colors */
-	gtk_tooltips_set_tip(tooltips, widget,
-			     _("Use colors in the player summary"), NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for the option to display the summary with colors */
+				    _("Use colors in the player summary"));
 	row++;
 
-	/* Label for the option to display keyboard accelerators in the toolbar */
 	widget =
+	    /* Label for the option to display keyboard accelerators in the toolbar */
 	    gtk_check_button_new_with_label(_("Toolbar with shortcuts"));
 	gtk_widget_show(widget);
 	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
@@ -992,14 +1011,26 @@ static void preferences_cb(void)
 				     toolbar_show_accelerators);
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(toolbar_shortcuts_cb), NULL);
-	/* Tooltip for the option to display keyboard accelerators in the toolbar */
-	gtk_tooltips_set_tip(tooltips, widget,
-			     _("Show keyboard shortcuts in the toolbar"),
-			     NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for the option to display keyboard accelerators in the toolbar */
+				    _(""
+				      "Show keyboard shortcuts in the toolbar"));
+	row++;
+
+	silent_mode_widget =
+	    /* Label for the option to disable all sounds */
+	    gtk_check_button_new_with_label(_("Silent mode"));
+	gtk_widget_show(silent_mode_widget);
+	gtk_table_attach_defaults(GTK_TABLE(layout), silent_mode_widget,
+				  0, 2, row, row + 1);
+	gtk_widget_set_tooltip_text(silent_mode_widget,
+				    /* Tooltip for the option to disable all sounds */
+				    _(""
+				      "In silent mode no sounds are made"));
 	row++;
 
-	/* Label for the option to announce when players/viewer enter */
 	widget =
+	    /* Label for the option to announce when players/viewers enter */
 	    gtk_check_button_new_with_label(_("Announce new players"));
 	gtk_widget_show(widget);
 	gtk_table_attach_defaults(GTK_TABLE(layout), widget,
@@ -1008,13 +1039,18 @@ static void preferences_cb(void)
 				     get_announce_player());
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(announce_player_cb), NULL);
-	/* Tooltip for the option to use sound */
-	gtk_tooltips_set_tip(tooltips, widget,
-			     _
-			     ("Make a sound when a new player or viewer enters the game"),
-			     NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for the option to use sound when players/viewers enter */
+				    _(""
+				      "Make a sound when a new player or viewer enters the game"));
 	row++;
 
+	/* Silent mode widget is connected an initialized after the announce button */
+	g_signal_connect(G_OBJECT(silent_mode_widget), "toggled",
+			 G_CALLBACK(silent_mode_cb), widget);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(silent_mode_widget),
+				     get_silent_mode());
+
 	/* Label for the option to use the 16:9 layout. */
 	widget = gtk_check_button_new_with_label(_("Use 16:9 layout"));
 	gtk_widget_show(widget);
@@ -1024,11 +1060,10 @@ static void preferences_cb(void)
 				     get_16_9_layout());
 	g_signal_connect(G_OBJECT(widget), "toggled",
 			 G_CALLBACK(toggle_16_9_cb), NULL);
-	/* Tooltip for 16:9 option. */
-	gtk_tooltips_set_tip(tooltips, widget,
-			     _
-			     ("Use a 16:9 friendly layout for the window"),
-			     NULL);
+	gtk_widget_set_tooltip_text(widget,
+				    /* Tooltip for 16:9 option. */
+				    _(""
+				      "Use a 16:9 friendly layout for the window"));
 	row++;
 
 }
@@ -1508,6 +1543,8 @@ GtkWidget *gui_build_interface(void)
 	set_color_summary(config_get_int_with_default
 			  ("settings/color_summary", TRUE));
 
+	set_silent_mode(config_get_int_with_default
+			("settings/silent_mode", FALSE));
 	set_announce_player(config_get_int_with_default
 			    ("settings/announce_player", TRUE));
 
@@ -1605,3 +1642,15 @@ void gui_set_show_no_setup_nodes(gboolean show)
 {
 	guimap_set_show_no_setup_nodes(gmap, show);
 }
+
+Map *frontend_get_map(void)
+{
+	g_return_val_if_fail(gmap != NULL, NULL);
+	return gmap->map;
+}
+
+void frontend_set_map(Map * map)
+{
+	g_assert(gmap != NULL);
+	gmap->map = map;
+}
