@@ -64,6 +64,9 @@ static void calculate_optimum_size(GtkWidget * area, gint size)
 
 	guimap_scale_with_radius(&bogus_map, size);
 
+	if (bogus_map.hex_radius <= MIN_HEX_RADIUS)
+		return;
+
 	fixedwidth = 0;
 	variablewidth = 0;
 
@@ -98,12 +101,16 @@ static void calculate_optimum_size(GtkWidget * area, gint size)
 		calculate_width(area, &poly, stock_num_cities(),
 				&fixedwidth, &variablewidth);
 	}
+	if (game_params->num_build_type[BUILD_CITY_WALL] > 0) {
+		poly.num_points = MAX_POINTS;
+		guimap_city_wall_polygon(&bogus_map, NULL, &poly);
+		calculate_width(area, &poly, stock_num_city_walls(),
+				&fixedwidth, &variablewidth);
+	}
 
 	new_size = bogus_map.hex_radius *
 	    (area->allocation.width - 75 - fixedwidth) / variablewidth;
 	if (new_size < bogus_map.hex_radius) {
-		if (new_size < 0)
-			new_size = 0;
 		calculate_optimum_size(area, new_size);
 	}
 }
@@ -255,6 +262,13 @@ static gint expose_identity_area_cb(GtkWidget * area,
 						 &poly,
 						 stock_num_cities());
 	}
+	if (game_params->num_build_type[BUILD_CITY_WALL] > 0) {
+		poly.num_points = MAX_POINTS;
+		guimap_city_wall_polygon(&bogus_map, NULL, &poly);
+		offset = draw_building_and_count(identity_gc, area, offset,
+						 &poly,
+						 stock_num_city_walls());
+	}
 
 	if (die1_num > 0 && die2_num > 0) {
 		show_die(identity_gc, area, area->allocation.width - 35,
