@@ -24,6 +24,7 @@
 #include "frontend.h"
 #include "cost.h"
 #include "histogram.h"
+#include "audio.h"
 
 /* local functions */
 static void frontend_state_turn(GuiEvent event);
@@ -405,7 +406,7 @@ void frontend_turn(void)
 		return;
 	}
 	set_gui_state(frontend_state_turn);
-	gdk_beep();
+	play_sound(SOUND_TURN);
 }
 
 /* development card actions */
@@ -733,7 +734,7 @@ static void place_robber_or_pirate_cb(MapElement hex,
 void frontend_steal_ship(void)
 {
 	MapElement hex;
-	hex.hex = map_pirate_hex(get_map());
+	hex.hex = map_pirate_hex(callbacks.get_map());
 
 	gui_cursor_set(STEAL_SHIP_CURSOR, can_edge_be_robbed, rob_edge,
 		       NULL, &hex);
@@ -743,7 +744,7 @@ void frontend_steal_ship(void)
 void frontend_steal_building(void)
 {
 	MapElement hex;
-	hex.hex = map_robber_hex(get_map());
+	hex.hex = map_robber_hex(callbacks.get_map());
 
 	gui_cursor_set(STEAL_BUILDING_CURSOR, can_building_be_robbed,
 		       rob_building, NULL, &hex);
@@ -879,5 +880,5 @@ void frontend_setup(G_GNUC_UNUSED unsigned num_settlements,
 		return;
 	}
 	set_gui_state(frontend_mode_setup);
-	gdk_beep();
+	play_sound(SOUND_TURN);
 }
