@@ -101,8 +101,8 @@ void monopoly_create_dlg(void)
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 
 	lbl =
-	    gtk_label_new(_
-			  ("Select the resource you wish to monopolise."));
+	    gtk_label_new(_(""
+			    "Select the resource you wish to monopolise."));
 	gtk_widget_show(lbl);
 	gtk_box_pack_start(GTK_BOX(vbox), lbl, TRUE, TRUE, 0);
 	gtk_misc_set_alignment(GTK_MISC(lbl), 0, 0.5);
