@@ -3,7 +3,7 @@
  *
  * Copyright (C) 1999 Dave Cole
  * Copyright (C) 2003, 2006 Bas Wijnen <shevek@fmf.nl>
- * Copyright (C) 2004 Roland Clobus <rclobus@bigfoot.com>
+ * Copyright (C) 2004-2008 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include "gtkbugs.h"
 #include "common_gtk.h"
 #include "player-icon.h"
+#include "audio.h"
 
 static void player_show_connected_at_iter(gint player_num,
 					  gboolean connected,
@@ -80,7 +81,6 @@ static Player players[MAX_PLAYERS];
 static GtkListStore *summary_store; /**< the player summary data */
 static GtkWidget *summary_widget; /**< the player summary widget */
 static gboolean summary_color_enabled = TRUE;
-static gboolean announce_player = FALSE;
 
 /** Structure to find combination of player and statistic */
 struct Player_statistic {
@@ -261,16 +261,6 @@ void set_color_summary(gboolean flag)
 	}
 }
 
-gboolean get_announce_player(void)
-{
-	return announce_player;
-}
-
-void set_announce_player(gboolean announce)
-{
-	announce_player = announce;
-}
-
 void frontend_new_statistics(gint player_num, StatisticType type,
 			     G_GNUC_UNUSED gint num)
 {
@@ -433,8 +423,8 @@ void frontend_player_name(gint player_num, const gchar * name)
 			   SUMMARY_COLUMN_TEXT, name, -1);
 
 	player_show_connected_at_iter(player_num, TRUE, &iter);
-	if (announce_player && callback_mode != MODE_INIT)
-		gdk_beep();
+	if (callback_mode != MODE_INIT)
+		play_sound(SOUND_ANNOUNCE);
 
 	chat_player_name(player_num, name);
 }
@@ -456,8 +446,8 @@ void frontend_viewer_name(gint viewer_num, const gchar * name)
 	player_create_find_player(viewer_num, &iter);
 	gtk_list_store_set(summary_store, &iter,
 			   SUMMARY_COLUMN_TEXT, name, -1);
-	if (announce_player && callback_mode != MODE_INIT)
-		gdk_beep();
+	if (callback_mode != MODE_INIT)
+		play_sound(SOUND_ANNOUNCE);
 
 	chat_player_name(viewer_num, name);
 }
