@@ -56,6 +56,7 @@ static Param game_params[] = {
 	{PARAM_V(num-players, PARAM_INT, num_players)},
 	{PARAM_V(sevens-rule, PARAM_INT, sevens_rule)},
 	{PARAM_V(victory-points, PARAM_INT, victory_points)},
+	{PARAM_V(check-victory-at-end-of-turn, PARAM_BOOL, check_victory_at_end_of_turn)},
 	{PARAM_V(num-roads, PARAM_INT, num_build_type[BUILD_ROAD])},
 	{PARAM_V(num-bridges, PARAM_INT, num_build_type[BUILD_BRIDGE])},
 	{PARAM_V(num-ships, PARAM_INT, num_build_type[BUILD_SHIP])},
@@ -189,12 +190,12 @@ struct nosetup_t {
 	gpointer user_data;
 };
 
-static gboolean find_no_setup(G_GNUC_UNUSED Map * map, Hex * hex,
-			      struct nosetup_t *data)
+static gboolean find_no_setup(const Hex * hex, gpointer closure)
 {
 	gint idx;
+	struct nosetup_t *data = closure;
 	for (idx = 0; idx < G_N_ELEMENTS(hex->nodes); ++idx) {
-		Node *node = hex->nodes[idx];
+		const Node *node = hex->nodes[idx];
 		if (node->no_setup) {
 			gchar buff[50];
 			if (node->x != hex->x || node->y != hex->y)
@@ -284,7 +285,7 @@ void params_write_lines(GameParams * params, gboolean write_secrets,
 		struct nosetup_t tmp;
 		tmp.user_data = user_data;
 		tmp.func = func;
-		map_traverse(params->map, (HexFunc) find_no_setup, &tmp);
+		map_traverse_const(params->map, find_no_setup, &tmp);
 	}
 }
 
@@ -634,9 +635,9 @@ WinnableState params_check_winnable_state(const GameParams * params,
 			return_value = PARAMS_NO_WIN;
 		} else {
 			*win_message =
-			    g_strdup(_
-				     ("It is possible that this "
-				      "game cannot be won."));
+			    g_strdup(_(""
+				       "It is possible that this "
+				       "game cannot be won."));
 			return_value = PARAMS_WIN_PERHAPS;
 		}
 	} else {
@@ -646,13 +647,13 @@ WinnableState params_check_winnable_state(const GameParams * params,
 		return_value = PARAMS_WIN_BUILD_ALL;
 	}
 	*point_specification =
-	    g_strdup_printf(_
-			    ("Required victory points: %d\n"
-			     "Points obtained by building all: %d\n"
-			     "Points in development cards: %d\n"
-			     "Longest road/largest army: %d+%d\n"
-			     "Maximum island discovery bonus: %d\n"
-			     "Total: %d"), target, building, development,
+	    g_strdup_printf(_(""
+			      "Required victory points: %d\n"
+			      "Points obtained by building all: %d\n"
+			      "Points in development cards: %d\n"
+			      "Longest road/largest army: %d+%d\n"
+			      "Maximum island discovery bonus: %d\n"
+			      "Total: %d"), target, building, development,
 			    road, army, max_island,
 			    building + development + road + army +
 			    max_island);
