@@ -2,7 +2,6 @@
 #include "game.h"
 #include <gtk/gtksignal.h>
 #include <gtk/gtktable.h>
-#include <gtk/gtktooltips.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkradiobutton.h>
@@ -51,7 +50,7 @@ static void add_row(GameRules * gr, const gchar * name,
 				  0, 2, row, row + 1);
 	*check = GTK_CHECK_BUTTON(check_btn);
 
-	gtk_tooltips_set_tip(gr->tooltips, check_btn, tooltip, NULL);
+	gtk_widget_set_tooltip_text(check_btn, tooltip);
 }
 
 /* Build the composite widget */
@@ -62,8 +61,6 @@ static void game_rules_init(GameRules * gr)
 	gint idx;
 	gint row;
 
-	gr->tooltips = gtk_tooltips_new();
-
 	gtk_table_resize(GTK_TABLE(gr), 5, 2);
 	gtk_table_set_row_spacings(GTK_TABLE(gr), 3);
 	gtk_table_set_col_spacings(GTK_TABLE(gr), 5);
@@ -84,30 +81,29 @@ static void game_rules_init(GameRules * gr)
 							(gr->
 							 radio_sevens[0]),
 							/* Sevens rule: reroll on 1st 2 turns */
-							_
-							("Reroll on 1st 2 turns"));
+							_(""
+							  "Reroll on 1st 2 turns"));
 	gr->radio_sevens[2] =
 	    gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON
 							(gr->
 							 radio_sevens[0]),
 							/* Sevens rule: reroll all 7s */
-							_
-							("Reroll all 7s"));
+							_(""
+							  "Reroll all 7s"));
 
 	vbox_sevens = gtk_vbox_new(TRUE, 2);
 	gtk_widget_show(vbox_sevens);
-	gtk_tooltips_set_tip(gr->tooltips, gr->radio_sevens[0],
-			     /* Tooltip for sevens rule normal */
-			     _("All sevens move the robber or pirate"),
-			     NULL);
-	gtk_tooltips_set_tip(gr->tooltips, gr->radio_sevens[1],
-			     /* Tooltip for sevens rule reroll on 1st 2 turns */
-			     _
-			     ("In the first two turns all sevens are rerolled"),
-			     NULL);
-	gtk_tooltips_set_tip(gr->tooltips, gr->radio_sevens[2],
-			     /* Tooltip for sevens rule reroll all */
-			     _("All sevens are rerolled"), NULL);
+	gtk_widget_set_tooltip_text(gr->radio_sevens[0],
+				    /* Tooltip for sevens rule normal */
+				    _(""
+				      "All sevens move the robber or pirate"));
+	gtk_widget_set_tooltip_text(gr->radio_sevens[1],
+				    /* Tooltip for sevens rule reroll on 1st 2 turns */
+				    _(""
+				      "In the first two turns all sevens are rerolled"));
+	gtk_widget_set_tooltip_text(gr->radio_sevens[2],
+				    /* Tooltip for sevens rule reroll all */
+				    _("All sevens are rerolled"));
 
 	for (idx = 0; idx < 3; ++idx) {
 		gtk_widget_show(gr->radio_sevens[idx]);
@@ -127,6 +123,9 @@ static void game_rules_init(GameRules * gr)
 		&gr->strict_trade);
 	add_row(gr, _("Domestic Trade"), _("Allow trade between players"),
 		row++, &gr->domestic_trade);
+	add_row(gr, _("Victory At End Of Turn"),
+		_("Check for victory only at end of turn"),
+		row++, &gr->check_victory_at_end_of_turn);
 }
 
 /* Create a new instance of the widget */
@@ -143,6 +142,7 @@ GtkWidget *game_rules_new_metaserver(void)
 	gtk_widget_hide(GTK_WIDGET(widget->use_pirate));
 	gtk_widget_hide(GTK_WIDGET(widget->strict_trade));
 	gtk_widget_hide(GTK_WIDGET(widget->domestic_trade));
+	gtk_widget_hide(GTK_WIDGET(widget->check_victory_at_end_of_turn));
 	return GTK_WIDGET(widget);
 }
 
@@ -237,3 +237,18 @@ gboolean game_rules_get_domestic_trade(GameRules * gr)
 	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
 					 (gr->domestic_trade));
 }
+
+void game_rules_set_victory_at_end_of_turn(GameRules * gr, gboolean val)
+{
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				     (gr->check_victory_at_end_of_turn),
+				     val);
+}
+
+gboolean game_rules_get_victory_at_end_of_turn(GameRules * gr)
+{
+	return
+	    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON
+					 (gr->
+					  check_victory_at_end_of_turn));
+}
