@@ -467,7 +467,7 @@ static void client_create_new_server(Client * client, gchar * line)
 	GList *list;
 	GSpawnFlags spawn_flags = G_SPAWN_STDOUT_TO_DEV_NULL |
 	    G_SPAWN_STDERR_TO_DEV_NULL;
-	gchar *child_argv[32];
+	gchar *child_argv[34];
 	gchar *port;
 	GError *error = NULL;
 
@@ -588,9 +588,11 @@ static void client_create_new_server(Client * client, gchar * line)
 	child_argv[n++] = g_strdup("-n");
 	child_argv[n++] = g_strdup(myhostname);
 	child_argv[n++] = g_strdup("-x");
+	child_argv[n++] = g_strdup("-t");
+	child_argv[n++] = g_strdup("1");
 	child_argv[n++] = g_strdup("-r");
 	child_argv[n] = NULL;
-	g_assert(n < 32);
+	g_assert(n < 34);
 
 	if (!g_spawn_async(NULL, child_argv, NULL, spawn_flags, NULL, NULL,
 			   NULL, &error)) {
@@ -1041,7 +1043,7 @@ static GOptionEntry commandline_entries[] = {
 	 N_("hostname")},
 	{"port-range", 'p', 0, G_OPTION_ARG_STRING, &port_range,
 	 /* Commandline meta-server: port-range */
-	 N_("Use this ports range when creating new games"),
+	 N_("Use this port range when creating new games"),
 	 /* Commandline meta-server: port-range argument */
 	 N_("from-to")},
 	{"debug", '\0', 0, G_OPTION_ARG_NONE, &enable_debug,
@@ -1123,6 +1125,7 @@ int main(int argc, char *argv[])
 #endif				/* HAVE_GETADDRINFO_ET_AL */
 		}
 	}
+	can_create_games = can_create_games && (port_range != NULL);
 
 	if (!myhostname)
 		myhostname = get_meta_server_name(FALSE);
