@@ -37,6 +37,8 @@
 /* network administration functions */
 comm_info *_accept_info = NULL;
 
+gint admin_dice_roll = 0;
+
 typedef enum {
 	BADCOMMAND,
 	SETPORT,
@@ -51,7 +53,8 @@ typedef enum {
 	QUIT,
 	MESSAGE,
 	HELP,
-	INFO
+	INFO,
+	FIXDICE
 } AdminCommandType;
 
 typedef struct {
@@ -77,7 +80,8 @@ static AdminCommand admin_commands[] = {
 	{ QUIT,           "quit",                FALSE, FALSE, FALSE },
 	{ MESSAGE,        "send-message",        TRUE,  FALSE, TRUE  },
 	{ HELP,           "help",                FALSE, FALSE, FALSE },
-	{ INFO,           "info",                FALSE, FALSE, FALSE }
+	{ INFO,           "info",                FALSE, FALSE, FALSE },
+	{ FIXDICE,        "fix-dice",            TRUE,  FALSE, FALSE },
 };
 /* *INDENT-ON* */
 
@@ -92,6 +96,7 @@ void admin_run_command(Session * admin_session, const gchar * line)
 	static gchar *server_port = NULL;
 	static gboolean register_server = TRUE;
 	static GameParams *params = NULL;
+	static Game *game = NULL;
 
 	if (!g_str_has_prefix(line, "admin")) {
 		net_printf(admin_session,
@@ -146,8 +151,10 @@ void admin_run_command(Session * admin_session, const gchar * line)
 			   command);
 	} else {
 		if (admin_commands[command_number].stop_server
-		    && server_is_running()) {
-			server_stop();
+		    && server_is_running(game)) {
+			server_stop(game);
+			game_free(game);
+			game = NULL;
 			net_write(admin_session, "INFO server stopped\n");
 		}
 		switch (admin_commands[command_number].type) {
@@ -169,14 +176,18 @@ void admin_run_command(Session * admin_session, const gchar * line)
 					server_port =
 					    g_strdup
 					    (PIONEERS_DEFAULT_GAME_PORT);
-				start_server(params, get_server_name(),
-					     server_port, register_server,
-					     meta_server_name, TRUE);
+				if (game != NULL)
+					game_free(game);
+				game =
+				    server_start(params, get_server_name(),
+						 server_port,
+						 register_server,
+						 meta_server_name, TRUE);
 				g_free(meta_server_name);
 			}
 			break;
 		case STOPSERVER:
-			server_stop();
+			server_stop(game);
 			break;
 		case REGISTERSERVER:
 			register_server = atoi(argument);
@@ -206,13 +217,13 @@ void admin_run_command(Session * admin_session, const gchar * line)
 		case QUIT:
 			net_close(admin_session);
 			/* Quit the server if the admin leaves */
-			if (!server_is_running())
+			if (!server_is_running(game))
 				exit(0);
 			break;
 		case MESSAGE:
 			g_strdelimit(argument, "|", '_');
-			if (server_is_running())
-				admin_broadcast(argument);
+			if (server_is_running(game))
+				admin_broadcast(game, argument);
 			break;
 		case HELP:
 			for (command_number = 1;
@@ -243,7 +254,7 @@ void admin_run_command(Session * admin_session, const gchar * line)
 				   register_server);
 			net_printf(admin_session,
 				   "INFO server running %d\n",
-				   server_is_running());
+				   server_is_running(game));
 			if (params) {
 				net_printf(admin_session, "INFO game %s\n",
 					   params->title);
@@ -263,7 +274,22 @@ void admin_run_command(Session * admin_session, const gchar * line)
 				net_printf(admin_session,
 					   "INFO no game set\n");
 			}
+			if (admin_dice_roll != 0)
+				net_printf(admin_session,
+					   "INFO dice fixed to %d\n",
+					   admin_dice_roll);
 			break;
+		case FIXDICE:
+			admin_dice_roll = CLAMP(atoi(argument), 0, 12);
+			if (admin_dice_roll == 1)
+				admin_dice_roll = 0;
+			if (admin_dice_roll != 0)
+				net_printf(admin_session,
+					   "INFO dice fixed to %d\n",
+					   admin_dice_roll);
+			else
+				net_printf(admin_session,
+					   "INFO dice rolled normally\n");
 		}
 	}
 	g_free(command);
