@@ -42,6 +42,7 @@
 #include "game-settings.h"	/* Custom widget */
 #include "game-rules.h"
 #include "theme.h"
+#include "metaserver.h"		/* Custom widget */
 
 #define MAINICON_FILE	"pioneers-server.png"
 
@@ -63,16 +64,13 @@ static GtkWidget *addcomputer_btn;	/* button to add computer players */
 static GtkWidget *launchclient_btn;	/* button to launch client window */
 
 static GtkWidget *start_btn;	/* start/stop the server */
-static GtkTooltips *tooltips;	/* tooltips */
 
 static GtkListStore *store;	/* shows player connection status */
-static gboolean is_running;	/* current server status */
-
+static Game *game = NULL;	/* the current game */
 
 static gchar *overridden_hostname;	/* override reported hostname */
 static gchar *server_port = NULL;	/* port of the game */
 static gboolean register_server = TRUE;	/* Register at the meta server */
-static const gchar *meta_server_name = NULL;	/* hostname of the meta server */
 static gboolean want_ai_chat = TRUE;
 static gboolean random_order = TRUE;	/* random seating order */
 static gboolean enable_debug = FALSE;
@@ -176,6 +174,9 @@ static void update_game_settings(const GameParams * params)
 				  params->num_players);
 	game_settings_set_victory_points(GAMESETTINGS(game_settings),
 					 params->victory_points);
+	game_rules_set_victory_at_end_of_turn(GAMERULES(game_rules),
+					      params->
+					      check_victory_at_end_of_turn);
 	game_rules_set_random_terrain(GAMERULES(game_rules),
 				      params->random_terrain);
 	game_rules_set_sevens_rule(GAMERULES(game_rules),
@@ -205,8 +206,6 @@ static void gui_set_server_state(gboolean running)
 	gboolean ai_settings_enabled = TRUE;
 	gchar *fullname;
 
-	is_running = running;
-
 	gtk_widget_set_sensitive(gtk_notebook_get_nth_page
 				 (GTK_NOTEBOOK(settings_notebook), 0),
 				 !running);
@@ -219,11 +218,11 @@ static void gui_set_server_state(gboolean running)
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(settings_notebook),
 				      running ? 1 : 0);
 	gtk_button_set_label(GTK_BUTTON(start_btn),
-			     running ? _("Stop server") :
-			     _("Start server"));
-	gtk_tooltips_set_tip(tooltips, start_btn,
-			     running ? _("Stop the server") :
-			     _("Start the server"), NULL);
+			     running ? _("Stop Server") :
+			     _("Start Server"));
+	gtk_widget_set_tooltip_text(start_btn,
+				    running ? _("Stop the server") :
+				    _("Start the server"));
 
 	fullname = g_find_program_in_path(PIONEERS_AI_PATH);
 	if (fullname) {
@@ -237,12 +236,13 @@ static void gui_set_server_state(gboolean running)
 static void start_clicked_cb(G_GNUC_UNUSED GtkButton * start_btn,
 			     G_GNUC_UNUSED gpointer user_data)
 {
-	if (is_running) {
-		if (server_stop())
-			gui_set_server_state(FALSE);
+	if (server_is_running(game)) {
+		server_stop(game);
+		gui_set_server_state(server_is_running(game));
 	} else {		/* not running */
 		const gchar *title;
 		GameParams *params;
+		gchar *meta_server_name;
 
 		title = select_game_get_active(SELECTGAME(select_game));
 		params = params_copy(game_list_find_item(title));
@@ -252,9 +252,12 @@ static void start_clicked_cb(G_GNUC_UNUSED GtkButton * start_btn,
 		cfg_set_victory_points(params,
 				       game_settings_get_victory_points
 				       (GAMESETTINGS(game_settings)));
+		params->check_victory_at_end_of_turn =
+		    game_rules_get_victory_at_end_of_turn(GAMERULES
+							  (game_rules));
 		cfg_set_sevens_rule(params,
-				    game_rules_get_sevens_rule
-				    (GAMERULES(game_rules)));
+				    game_rules_get_sevens_rule(GAMERULES
+							       (game_rules)));
 		cfg_set_terrain_type(params,
 				     game_rules_get_random_terrain
 				     (GAMERULES(game_rules)));
@@ -266,10 +269,17 @@ static void start_clicked_cb(G_GNUC_UNUSED GtkButton * start_btn,
 		    game_rules_get_domestic_trade(GAMERULES(game_rules));
 		update_game_settings(params);
 
+		meta_server_name = metaserver_get(METASERVER(meta_entry));
+
 		g_assert(server_port != NULL);
-		if (start_server
-		    (params, overridden_hostname, server_port,
-		     register_server, meta_server_name, random_order)) {
+
+		if (game != NULL)
+			game_free(game);
+		game =
+		    server_start(params, overridden_hostname, server_port,
+				 register_server, meta_server_name,
+				 random_order);
+		if (server_is_running(game)) {
 			gui_set_server_state(TRUE);
 			config_set_string("server/meta-server",
 					  meta_server_name);
@@ -287,6 +297,9 @@ static void start_clicked_cb(G_GNUC_UNUSED GtkButton * start_btn,
 				       params->num_players);
 			config_set_int("game/victory-points",
 				       params->victory_points);
+			config_set_int("game/check-victory-at-end-of-turn",
+				       params->
+				       check_victory_at_end_of_turn);
 			config_set_int("game/sevens-rule",
 				       params->sevens_rule);
 			config_set_int("game/use-pirate",
@@ -297,6 +310,7 @@ static void start_clicked_cb(G_GNUC_UNUSED GtkButton * start_btn,
 				       params->domestic_trade);
 		}
 		params_free(params);
+		g_free(meta_server_name);
 	}
 }
 
@@ -340,7 +354,7 @@ static void addcomputer_clicked_cb(G_GNUC_UNUSED GtkButton * start_btn,
 				   G_GNUC_UNUSED gpointer user_data)
 {
 	g_assert(server_port != NULL);
-	new_computer_player(NULL, server_port, want_ai_chat);
+	add_computer_player(game, want_ai_chat);
 	config_set_int("ai/enable-chat", want_ai_chat);
 }
 
@@ -368,8 +382,8 @@ static void gui_player_rename(void *data)
 
 static gboolean everybody_left(G_GNUC_UNUSED gpointer data)
 {
-	if (server_stop())
-		gui_set_server_state(FALSE);
+	server_stop(game);
+	gui_set_server_state(server_is_running(game));
 	return FALSE;
 }
 
@@ -428,25 +442,12 @@ static void overridden_hostname_changed_cb(GtkEntry * widget,
 	overridden_hostname = g_strdup(text);
 }
 
-static void meta_server_changed_cb(GtkWidget * widget,
-				   G_GNUC_UNUSED gpointer user_data)
-{
-	const gchar *text;
-
-	text = gtk_entry_get_text(GTK_ENTRY(widget));
-	while (*text != '\0' && isspace(*text))
-		text++;
-	meta_server_name = text;
-}
-
 static GtkWidget *build_game_settings(GtkWidget * parent,
 				      GtkWindow * main_window)
 {
 	GtkWidget *frame;
 	GtkWidget *vbox;
 
-	tooltips = gtk_tooltips_new();
-
 	frame = gtk_frame_new(_("Game Parameters"));
 	gtk_widget_show(frame);
 	gtk_box_pack_start(GTK_BOX(parent), frame, FALSE, TRUE, 0);
@@ -477,8 +478,6 @@ static GtkWidget *build_game_rules(GtkWidget * parent)
 	GtkWidget *frame;
 	GtkWidget *vbox;
 
-	tooltips = gtk_tooltips_new();
-
 	frame = gtk_frame_new(_("Rules"));
 	gtk_widget_show(frame);
 	gtk_box_pack_start(GTK_BOX(parent), frame, FALSE, TRUE, 0);
@@ -524,9 +523,9 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	GtkWidget *label;
 	GtkWidget *scroll_win;
 	GtkWidget *message_text;
-	GtkTooltips *tooltips;
 	gint novar;
 	gboolean default_returned;
+	gchar *meta_server_name;
 	gchar *gamename;
 	gint temp;
 	GameParams *params;
@@ -534,8 +533,6 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
-	tooltips = gtk_tooltips_new();
-
 	vbox = gtk_vbox_new(FALSE, 5);
 	gtk_widget_show(vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
@@ -582,6 +579,11 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	temp = config_get_int("game/victory-points", &default_returned);
 	if (!default_returned)
 		cfg_set_victory_points(params, temp);
+	temp =
+	    config_get_int("game/victory-at-end-of-turn",
+			   &default_returned);
+	if (!default_returned)
+		params->check_victory_at_end_of_turn = temp;
 	temp = config_get_int("game/sevens-rule", &default_returned);
 	if (!default_returned)
 		cfg_set_sevens_rule(params, temp);
@@ -622,8 +624,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	gtk_table_attach(GTK_TABLE(table), port_entry, 1, 2, 0, 1,
 			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
 			 0);
-	gtk_tooltips_set_tip(tooltips, port_entry,
-			     _("The port for the game server"), NULL);
+	gtk_widget_set_tooltip_text(port_entry,
+				    _("The port for the game server"));
 
 	register_toggle =
 	    gtk_check_button_new_with_label(_("Register Server"));
@@ -633,9 +635,9 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 			 0);
 	g_signal_connect(G_OBJECT(register_toggle), "toggled",
 			 G_CALLBACK(register_toggle_cb), NULL);
-	gtk_tooltips_set_tip(tooltips, register_toggle,
-			     _("Register this game at the meta server"),
-			     NULL);
+	gtk_widget_set_tooltip_text(register_toggle,
+				    _(""
+				      "Register this game at the meta server"));
 
 	label = gtk_label_new(_("Meta Server"));
 	gtk_widget_show(label);
@@ -643,15 +645,11 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 
-	meta_entry = gtk_entry_new();
-	g_signal_connect(G_OBJECT(meta_entry), "changed",
-			 G_CALLBACK(meta_server_changed_cb), NULL);
+	meta_entry = metaserver_new();
 	gtk_widget_show(meta_entry);
 	gtk_table_attach(GTK_TABLE(table), meta_entry, 1, 2, 2, 3,
 			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0,
 			 0);
-	gtk_tooltips_set_tip(tooltips, meta_entry,
-			     _("The address of the meta server"), NULL);
 
 	label = gtk_label_new(_("Reported Hostname"));
 	gtk_widget_show(label);
@@ -666,10 +664,10 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	gtk_table_attach(GTK_TABLE(table), overridden_hostname_entry, 1, 2,
 			 3, 4, GTK_EXPAND | GTK_FILL,
 			 GTK_EXPAND | GTK_FILL, 0, 0);
-	gtk_tooltips_set_tip(tooltips, overridden_hostname_entry,
-			     _
-			     ("The public name of this computer (needed when playing behind a firewall)"),
-			     NULL);
+	gtk_widget_set_tooltip_text(overridden_hostname_entry,
+				    _(""
+				      "The public name of this computer "
+				      "(needed when playing behind a firewall)"));
 
 	random_toggle =
 	    gtk_check_button_new_with_label(_("Random Turn Order"));
@@ -679,8 +677,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 			 0);
 	g_signal_connect(G_OBJECT(random_toggle), "toggled",
 			 G_CALLBACK(random_toggle_cb), NULL);
-	gtk_tooltips_set_tip(tooltips, random_toggle,
-			     _("Randomize turn order"), NULL);
+	gtk_widget_set_tooltip_text(random_toggle,
+				    _("Randomize turn order"));
 
 	/* Initialize server-settings */
 	server_port = config_get_string("server/port="
@@ -694,7 +692,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	    || !strncmp(meta_server_name, "gnocatan.debian.net",
 			strlen(meta_server_name) + 1))
 		meta_server_name = get_meta_server_name(TRUE);
-	gtk_entry_set_text(GTK_ENTRY(meta_entry), meta_server_name);
+	metaserver_add(METASERVER(meta_entry), meta_server_name);
+	g_free(meta_server_name);
 
 	novar = 0;
 	overridden_hostname =
@@ -752,11 +751,9 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	/* The theme should decide if hints are used */
 	/* gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(label), TRUE); */
 	gtk_container_add(GTK_CONTAINER(scroll_win), label);
-	tooltips = gtk_tooltips_new();
-	gtk_tooltips_set_tip(tooltips, label,
-			     _
-			     ("Shows all players and viewers connected to the server"),
-			     NULL);
+	gtk_widget_set_tooltip_text(label,
+				    _(""
+				      "Shows all players and viewers connected to the server"));
 
 	/* Now create columns */
 	column =
@@ -766,9 +763,9 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 						     PLAYER_COLUMN_CONNECTED,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(label), column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Is the player currently connected?"),
-			     NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _(""
+				      "Is the player currently connected?"));
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Name"),
 						     gtk_cell_renderer_text_new
@@ -776,8 +773,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 						     PLAYER_COLUMN_NAME,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(label), column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Name of the player"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Name of the player"));
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Location"),
 						     gtk_cell_renderer_text_new
@@ -785,8 +782,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 						     PLAYER_COLUMN_LOCATION,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(label), column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Host name of the player"), NULL);
+	gtk_widget_set_tooltip_text(column->button,
+				    _("Host name of the player"));
 
 	renderer = gtk_cell_renderer_text_new();
 	column =
@@ -796,16 +793,14 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 						     NULL);
 	g_object_set(renderer, "xalign", 1.0f, NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(label), column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Player number"), NULL);
+	gtk_widget_set_tooltip_text(column->button, _("Player number"));
 
 	renderer = gtk_cell_renderer_text_new();
 	column =
 	    gtk_tree_view_column_new_with_attributes(_("Role"), renderer,
 						     NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(label), column);
-	gtk_tooltips_set_tip(tooltips, column->button,
-			     _("Player of viewer"), NULL);
+	gtk_widget_set_tooltip_text(column->button, _("Player of viewer"));
 
 	gtk_tree_view_column_set_cell_data_func(column, renderer,
 						my_cell_player_viewer_to_text,
@@ -822,8 +817,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 			   FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(launchclient_btn), "clicked",
 			 G_CALLBACK(launchclient_clicked_cb), NULL);
-	gtk_tooltips_set_tip(tooltips, launchclient_btn,
-			     _("Launch the Pioneers Client"), NULL);
+	gtk_widget_set_tooltip_text(launchclient_btn,
+				    _("Launch the Pioneers Client"));
 
 	ai_frame = gtk_frame_new(_("Computer Players"));
 	gtk_widget_show(ai_frame);
@@ -839,8 +834,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	gtk_box_pack_start(GTK_BOX(vbox_ai), chat_toggle, TRUE, TRUE, 0);
 	g_signal_connect(G_OBJECT(chat_toggle), "toggled",
 			 G_CALLBACK(chat_toggle_cb), NULL);
-	gtk_tooltips_set_tip(tooltips, chat_toggle,
-			     _("Enable chat messages"), NULL);
+	gtk_widget_set_tooltip_text(chat_toggle,
+				    _("Enable chat messages"));
 
 	want_ai_chat = config_get_int_with_default("ai/enable-chat", TRUE);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chat_toggle),
@@ -853,8 +848,9 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 			   0);
 	g_signal_connect(G_OBJECT(addcomputer_btn), "clicked",
 			 G_CALLBACK(addcomputer_clicked_cb), NULL);
-	gtk_tooltips_set_tip(tooltips, addcomputer_btn,
-			     _("Add a computer player to the game"), NULL);
+	gtk_widget_set_tooltip_text(addcomputer_btn,
+				    _(""
+				      "Add a computer player to the game"));
 
 	start_btn = gtk_button_new();
 	gtk_widget_show(start_btn);
@@ -880,8 +876,8 @@ static GtkWidget *build_interface(GtkWindow * main_window)
 	gtk_container_add(GTK_CONTAINER(scroll_win), message_text);
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(message_text),
 				    GTK_WRAP_WORD);
-	gtk_tooltips_set_tip(tooltips, message_text,
-			     _("Messages from the server"), NULL);
+	gtk_widget_set_tooltip_text(message_text,
+				    _("Messages from the server"));
 	message_window_set_text(message_text);
 
 	gui_set_server_state(FALSE);
@@ -902,6 +898,8 @@ static void check_vp_cb(G_GNUC_UNUSED GObject * caller,
 	cfg_set_victory_points(params,
 			       game_settings_get_victory_points
 			       (GAMESETTINGS(game_settings)));
+	params->check_victory_at_end_of_turn =
+	    game_rules_get_victory_at_end_of_turn(GAMERULES(game_rules));
 	cfg_set_sevens_rule(params,
 			    game_rules_get_sevens_rule
 			    (GAMERULES(game_rules)));
@@ -940,10 +938,10 @@ void game_is_over(G_GNUC_UNUSED Game * game)
 	log_message(MSG_INFO, _("The game is over.\n"));
 }
 
-void request_server_stop(void)
+void request_server_stop(Game * game)
 {
-	if (server_stop())
-		gui_set_server_state(FALSE);
+	server_stop(game);
+	gui_set_server_state(server_is_running(game));
 }
 
 static GOptionEntry commandline_entries[] = {
