@@ -130,14 +130,14 @@ static GOptionEntry commandline_other_entries[] = {
 	 N_("Admin port to listen on"), PIONEERS_DEFAULT_ADMIN_PORT},
 	{"admin-wait", 's', 0, G_OPTION_ARG_NONE, &disable_game_start,
 	 /* Commandline server-console: admin-wait */
-	 N_
-	 ("Don't start game immediately, wait for a command on admin port"),
+	 N_(""
+	    "Don't start game immediately, wait for a command on admin port"),
 	 NULL},
 	{"fixed-seating-order", 0, 0, G_OPTION_ARG_NONE,
 	 &fixed_seating_order,
 	 /* Commandline server-console: fixed-seating-order */
-	 N_
-	 ("Give players numbers according to the order they enter the game"),
+	 N_(""
+	    "Give players numbers according to the order they enter the game"),
 	 NULL},
 	{"debug", '\0', 0, G_OPTION_ARG_NONE, &enable_debug,
 	 /* Commandline option of server: enable debug logging */
@@ -152,6 +152,7 @@ int main(int argc, char *argv[])
 	GOptionGroup *context_group;
 	GError *error = NULL;
 	GameParams *params;
+	Game *game = NULL;
 
 	/* set the UI driver to Glib_Driver, since we're using glib */
 	set_ui_driver(&Glib_Driver);
@@ -179,8 +180,8 @@ int main(int argc, char *argv[])
 					   /* Commandline server-console: Short description of meta group */
 					   _("Meta-server Options"),
 					   /* Commandline server-console: Long description of meta group */
-					   _
-					   ("Options for the meta-server"),
+					   _(""
+					     "Options for the meta-server"),
 					   NULL, NULL);
 	g_option_group_set_translation_domain(context_group, PACKAGE);
 	g_option_group_add_entries(context_group,
@@ -219,8 +220,9 @@ int main(int argc, char *argv[])
 			admin_port = g_strdup(PIONEERS_DEFAULT_ADMIN_PORT);
 
 	if (game_title && game_file) {
-		g_print
-		    ("Cannot set game title and filename at the same time");
+		/* server-console commandline error */
+		g_print(_(""
+			  "Cannot set game title and filename at the same time\n"));
 		return 2;
 	}
 	if (game_file == NULL) {
@@ -233,7 +235,8 @@ int main(int argc, char *argv[])
 		params = cfg_set_game_file(game_file);
 	}
 	if (params == NULL) {
-		g_print("Could not set the game");
+		/* server-console commandline error */
+		g_print(_("Cannot load the parameters for the game\n"));
 		return 3;
 	}
 
@@ -261,38 +264,40 @@ int main(int argc, char *argv[])
 	if (terrain != -1)
 		cfg_set_terrain_type(params, terrain ? 1 : 0);
 
-	if (timeout)
-		cfg_set_timeout(timeout);
-
 	net_init();
 
 	if (admin_port != NULL)
 		admin_listen(admin_port);
 
-	if (!disable_game_start) {
-		if (start_server
-		    (params, hostname, server_port, register_server,
-		     meta_server_name, !fixed_seating_order)) {
-			for (i = 0; i < num_ai_players; ++i)
-				new_computer_player(NULL, server_port,
-						    TRUE);
+	if (disable_game_start && admin_port == NULL) {
+		/* server-console commandline error */
+		g_print(_(""
+			  "Admin port is not set, "
+			  "cannot disable game start too\n"));
+		return 4;
 
-			event_loop = g_main_loop_new(NULL, FALSE);
-			g_main_loop_run(event_loop);
-			g_main_loop_unref(event_loop);
-		}
-	} else {
-		/* Ugly... But needed to preserve the original functionality
-		   if the disable_game_start flag is set... Even if it doesn't
-		   really -do- anything. */
-		for (i = 0; i < num_ai_players; ++i)
-			new_computer_player(NULL, server_port, TRUE);
-
-		event_loop = g_main_loop_new(NULL, FALSE);
-		g_main_loop_run(event_loop);
-		g_main_loop_unref(event_loop);
 	}
 
+	if (!disable_game_start) {
+		game =
+		    server_start(params, hostname, server_port,
+				 register_server, meta_server_name,
+				 !fixed_seating_order);
+	}
+	if (game != NULL) {
+		game->no_player_timeout = timeout;
+		num_ai_players =
+		    CLAMP(num_ai_players, 0, game->params->num_players);
+		for (i = 0; i < num_ai_players; ++i)
+			add_computer_player(game, TRUE);
+	}
+
+	event_loop = g_main_loop_new(NULL, FALSE);
+	g_main_loop_run(event_loop);
+	g_main_loop_unref(event_loop);
+	game_free(game);
+	game = NULL;
+
 	net_finish();
 
 	g_free(hostname);
@@ -318,8 +323,11 @@ void game_is_over(Game * game)
 	}
 }
 
-void request_server_stop(void)
+void request_server_stop(Game * game)
 {
-	server_stop();
-	g_main_loop_quit(event_loop);
+	if (server_stop(game)) {
+		game_free(game);
+		game = NULL;
+		g_main_loop_quit(event_loop);
+	}
 }
