@@ -38,8 +38,9 @@
 typedef enum {
 	V0_10, /**< Lowest supported version */
 	V0_11, /**< City walls, player style, robber undo */
+	V0_12, /**< Trade protocol simplified */
 	FIRST_VERSION = V0_10,
-	LATEST_VERSION = V0_11
+	LATEST_VERSION = V0_12
 } ClientVersionType;
 
 #define TERRAIN_DEFAULT	0
@@ -96,6 +97,9 @@ struct Game {
 	gint player_list_use_count;	/* # functions is in use by */
 	gint num_players;	/* current number of players in the game */
 
+	gint tournament_countdown;	/* number of remaining minutes before AIs are added */
+	guint tournament_timer;	/* timer id */
+
 	gboolean double_setup;
 	gboolean reverse_setup;
 	GList *setup_player;
@@ -120,8 +124,12 @@ struct Game {
 	gint *develop_deck;	/* development cards */
 	gint develop_next;	/* next development card to deal */
 
+	gboolean is_running;	/* is the server currently running? */
 	gchar *server_port;	/* port to run game on */
 	gboolean random_order;	/* is turn order randomized? */
+
+	gint no_player_timeout;	/* time to wait for players */
+	guint no_player_timer;	/* glib timer identifier */
 };
 
 /**** global variables ****/
@@ -163,7 +171,9 @@ typedef enum {
 	PB_SILENT,
 	PB_OTHERS
 } BroadcastType;
-Player *player_new(Game * game, int fd, gchar * location);
+gchar *player_new_computer_player(Game * game);
+Player *player_new(Game * game, const gchar * name, const gchar * style);
+Player *player_new_connection(Game * game, int fd, const gchar * location);
 Player *player_by_num(Game * game, gint num);
 void player_set_name(Player * player, gchar * name);
 Player *player_none(Game * game);
@@ -199,7 +209,7 @@ gboolean player_is_viewer(Game * game, gint player_num);
 /* pregame.c */
 gboolean mode_pre_game(Player * player, gint event);
 gboolean mode_setup(Player * player, gint event);
-gboolean send_gameinfo_uncached(Map * map, Hex * hex, void *player);
+gboolean send_gameinfo_uncached(const Hex * hex, void *player);
 void next_setup_player(Game * game);
 
 /* resource.c */
@@ -221,19 +231,17 @@ gboolean mode_select_robbed(Player * player, gint event);
 void robber_undo(Player * player);
 
 /* server.c */
-void start_timeout(void);
-void stop_timeout(void);
+void start_timeout(Game * game);
+void stop_timeout(Game * game);
 gint get_rand(gint range);
 Game *game_new(const GameParams * params);
 void game_free(Game * game);
-gint new_computer_player(const gchar * server, const gchar * port,
-			 gboolean want_chat);
-gboolean server_startup(const GameParams * params, const gchar * hostname,
-			const gchar * port, gboolean meta_register,
-			const gchar * meta_name_server,
-			gboolean random_order);
-gboolean server_stop(void);
-gboolean server_is_running(void);
+gint add_computer_player(Game * game, gboolean want_chat);
+Game *server_start(const GameParams * params, const gchar * hostname,
+		   const gchar * port, gboolean register_server,
+		   const gchar * meta_server_name, gboolean random_order);
+gboolean server_stop(Game * game);
+gboolean server_is_running(Game * game);
 gint accept_connection(gint in_fd, gchar ** location);
 void server_cleanup_static_data(void);
 
@@ -251,24 +259,17 @@ void cfg_set_victory_points(GameParams * params, gint victory_points);
 void cfg_set_terrain_type(GameParams * params, gint terrain_type);
 void cfg_set_tournament_time(GameParams * params, gint tournament_time);
 void cfg_set_quit(GameParams * params, gboolean quitdone);
-void cfg_set_timeout(gint to);
-void admin_broadcast(const gchar * message);
-
-/* callbacks related to server starting / stopping */
-gboolean start_server(const GameParams * params, const gchar * hostname,
-		      const gchar * port, gboolean register_server,
-		      const gchar * meta_server_name,
-		      gboolean random_order);
+void admin_broadcast(Game * game, const gchar * message);
 
 /* initialize the server */
 void server_init(void);
 void game_is_over(Game * game);
-void request_server_stop(void);
+void request_server_stop(Game * game);
 
 /* trade.c */
 void trade_perform_maritime(Player * player,
 			    gint ratio, Resource supply, Resource receive);
-gboolean mode_wait_quote_exit(Player * player, gint event);
+gboolean mode_domestic_quote_rejected(Player * player, gint event);
 gboolean mode_domestic_quote(Player * player, gint event);
 void trade_finish_domestic(Player * player);
 void trade_accept_domestic(Player * player,
@@ -281,7 +282,12 @@ void trade_begin_domestic(Player * player, gint * supply, gint * receive);
 gboolean mode_idle(Player * player, gint event);
 gboolean mode_turn(Player * player, gint event);
 void turn_next_player(Game * game);
-void check_victory(Player * player);
+/** Check whether this player has won the game.
+ *  If so, return TRUE and set all state machines to idle
+ *  @param player Has this player won?
+ *  @return TRUE if the given player has won
+ */
+gboolean check_victory(Player * player);
 
 /* gold.c */
 gboolean gold_limited_bank(const Game * game, int limit,
