@@ -25,6 +25,7 @@
 #include "buildrec.h"
 #include "cost.h"
 #include "server.h"
+#include "admin.h"
 
 static void build_add(Player * player, BuildType type, gint x, gint y,
 		      gint pos)
@@ -181,8 +182,7 @@ static void build_add(Player * player, BuildType type, gint x, gint y,
 	} else {
 		/* New building: make sure it connects to a road
 		 */
-		if (!map_building_connect_ok
-		    (map, player->num, type, x, y, pos)) {
+		if (!map_building_connect_ok(map, player->num, x, y, pos)) {
 			player_send(player, FIRST_VERSION, LATEST_VERSION,
 				    "ERR bad-pos\n");
 			return;
@@ -252,8 +252,8 @@ static void build_add(Player * player, BuildType type, gint x, gint y,
 					       first_island ?
 					       N_("Island Discovery Bonus")
 					       :
-					       N_
-					       ("Additional Island Bonus"),
+					       N_(""
+						  "Additional Island Bonus"),
 					       points);
 			player->islands_discovered++;
 		}
@@ -358,19 +358,19 @@ typedef struct {
 	int roll;
 } GameRoll;
 
-static gboolean distribute_resources(G_GNUC_UNUSED Map * map, Hex * hex,
-				     GameRoll * data)
+static gboolean distribute_resources(const Hex * hex, gpointer closure)
 {
 	int idx;
+	GameRoll *data = closure;
 
 	if (hex->roll != data->roll || hex->robber)
 		/* return false so the traverse function continues */
 		return FALSE;
 
 	for (idx = 0; idx < G_N_ELEMENTS(hex->nodes); idx++) {
-		Node *node = hex->nodes[idx];
+		const Node *node = hex->nodes[idx];
 		Player *player;
-		int num;
+		gint num;
 
 		if (node->type == BUILD_NONE)
 			continue;
@@ -384,8 +384,8 @@ static gboolean distribute_resources(G_GNUC_UNUSED Map * map, Hex * hex,
 		} else {
 			/* This should be fixed at some point. */
 			log_message(MSG_ERROR,
-				    _
-				    ("Tried to assign resources to NULL player.\n"));
+				    _(""
+				      "Tried to assign resources to NULL player.\n"));
 		}
 	}
 
@@ -393,12 +393,16 @@ static gboolean distribute_resources(G_GNUC_UNUSED Map * map, Hex * hex,
 	return FALSE;
 }
 
-void check_victory(Player * player)
+gboolean check_victory(Player * player)
 {
 	Game *game = player->game;
 	GList *list;
 	gint points;
 
+	if (player->num != game->curr_player)
+		/* Only the player that has the turn can win */
+		return FALSE;
+
 	points = player->num_settlements
 	    + player->num_cities * 2 + player->develop_points;
 
@@ -431,7 +435,9 @@ void check_victory(Player * player)
 		meta_unregister();
 
 		game_is_over(game);
+		return TRUE;
 	}
+	return FALSE;
 }
 
 /* Handle all actions that a player may perform in a turn
@@ -440,11 +446,11 @@ gboolean mode_turn(Player * player, gint event)
 {
 	StateMachine *sm = player->sm;
 	Game *game = player->game;
-	Map *map = game->params->map;
+	const Map *map = game->params->map;
 	BuildType build_type;
 	DevelType devel_type;
 	gint x, y, pos;
-	gint quote_num, partner_num, idx, ratio;
+	gint idx, ratio;
 	Resource supply_type, receive_type;
 	gint supply[NO_RESOURCE], receive[NO_RESOURCE];
 	gint sx, sy, spos, dx, dy, dpos;
@@ -480,6 +486,17 @@ gboolean mode_turn(Player * player, gint event)
 			/* sevens_rule == 0: don't reroll anything */
 			break;
 		}
+		/* The administrator can override the dice */
+		if (admin_dice_roll >= 2) {
+			game->die1 = admin_dice_roll > 6 ? 6 : 1;
+			game->die2 = admin_dice_roll - game->die1;
+			roll = admin_dice_roll;
+			player_broadcast(player, PB_SILENT, FIRST_VERSION,
+					 LATEST_VERSION, "NOTE %s\n",
+					 /* Cheat mode has been activated */
+					 N_(""
+					    "The dice roll has been determined by the administrator."));
+		}
 
 		/* let people know what we rolled */
 		player_broadcast(player, PB_RESPOND, FIRST_VERSION,
@@ -497,7 +514,7 @@ gboolean mode_turn(Player * player, gint event)
 		resource_start(game);
 		data.game = game;
 		data.roll = roll;
-		map_traverse(map, (HexFunc) distribute_resources, &data);
+		map_traverse_const(map, distribute_resources, &data);
 		/* distribute resources and gold (includes resource_end) */
 		distribute_first(list_from_player(player));
 		return TRUE;
@@ -511,9 +528,11 @@ gboolean mode_turn(Player * player, gint event)
 		}
 		/* Ok, finish turn */
 		player_send(player, FIRST_VERSION, LATEST_VERSION, "OK\n");
-		/* pop the state machine back to idle */
-		sm_pop(sm);
-		turn_next_player(game);
+		if (!check_victory(player)) {
+			/* game isn't over, so pop the state machine back to idle */
+			sm_pop(sm);
+			turn_next_player(game);
+		}
 		return TRUE;
 	}
 	if (sm_recv(sm, "buy-develop")) {
@@ -522,7 +541,8 @@ gboolean mode_turn(Player * player, gint event)
 	}
 	if (sm_recv(sm, "play-develop %d", &idx, &devel_type)) {
 		develop_play(player, idx);
-		check_victory(player);
+		if (!game->params->check_victory_at_end_of_turn)
+			check_victory(player);
 		return TRUE;
 	}
 	if (sm_recv(sm, "maritime-trade %d supply %r receive %r",
@@ -538,24 +558,18 @@ gboolean mode_turn(Player * player, gint event)
 		trade_begin_domestic(player, supply, receive);
 		return TRUE;
 	}
-	if (sm_recv
-	    (sm,
-	     "domestic-trade accept player %d quote %d supply %R receive %R",
-	     &partner_num, &quote_num, supply, receive)) {
-		trade_accept_domestic(player, partner_num, quote_num,
-				      supply, receive);
-		return TRUE;
-	}
 	if (sm_recv(sm, "build %B %d %d %d", &build_type, &x, &y, &pos)) {
 		build_add(player, build_type, x, y, pos);
-		check_victory(player);
+		if (!game->params->check_victory_at_end_of_turn)
+			check_victory(player);
 		return TRUE;
 	}
 	if (sm_recv
 	    (sm, "move %d %d %d %d %d %d", &sx, &sy, &spos, &dx, &dy,
 	     &dpos)) {
 		build_move(player, sx, sy, spos, dx, dy, dpos);
-		check_victory(player);
+		if (!game->params->check_victory_at_end_of_turn)
+			check_victory(player);
 		return TRUE;
 	}
 	if (sm_recv(sm, "undo")) {
